import type { Json, User } from "@thirdweb-dev/auth";
/**
 * @auth
 */
export interface UserWithData<TData extends Json = Json, TContext extends Json = Json> extends User<TContext> {
    data?: TData;
}
/**
 * Hook for retrieving information about the currently signed-in user using [auth](https://portal.thirdweb.com/wallets/auth).
 *
 * Useful to get the user's address and session data, or `undefined` if no user is signed in.
 *
 * ```jsx
 * import { useUser } from "@thirdweb-dev/react";
 *
 * function App() {
 *   const { user, isLoggedIn, isLoading } = useUser();
 * }
 * ```
 *
 * @auth
 *
 */
export declare function useUser<TData extends Json = Json, TContext extends Json = Json>(): {
    user: UserWithData<TData, TContext> | undefined;
    isLoggedIn: boolean;
    isLoading: boolean;
};
//# sourceMappingURL=useUser.d.ts.map